==> jc-1.4.0.tar.gz: soot/AbstractUnitAllMapTo.h <==
// public class soot.AbstractUnitAllMapTo

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c7382c60132d0b2c java_util_AbstractMap
// @dep_class 16e0c0c67a652321 soot_AbstractUnitAllMapTo

// header file dependencies
// @dep_header java_util_AbstractMap

#include "java/util/AbstractMap.h"

#ifndef _JC_soot_AbstractUnitAllMapTo_H_
#define _JC_soot_AbstractUnitAllMapTo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_soot_AbstractUnitAllMapTo$sub_refs	_jc_soot_AbstractUnitAllMapTo$sub_refs;
typedef struct _jc_soot_AbstractUnitAllMapTo$sub_nonrefs	_jc_soot_AbstractUnitAllMapTo$sub_nonrefs;
typedef struct _jc_soot_AbstractUnitAllMapTo$refs	_jc_soot_AbstractUnitAllMapTo$refs;
typedef struct _jc_soot_AbstractUnitAllMapTo$nonrefs	_jc_soot_AbstractUnitAllMapTo$nonrefs;
typedef struct _jc_soot_AbstractUnitAllMapTo$object	_jc_soot_AbstractUnitAllMapTo$object;

typedef const struct _jc_soot_AbstractUnitAllMapTo$vmethods	_jc_soot_AbstractUnitAllMapTo$vmethods;
typedef const struct _jc_soot_AbstractUnitAllMapTo$vtable	_jc_soot_AbstractUnitAllMapTo$vtable;
typedef const struct _jc_soot_AbstractUnitAllMapTo$vtype	_jc_soot_AbstractUnitAllMapTo$vtype;

// Constructors
extern void _jc_soot_AbstractUnitAllMapTo$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_soot_AbstractUnitAllMapTo$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern struct _jc_object *_jc_soot_AbstractUnitAllMapTo$method$entrySet$e1cf6e695274e51f(_jc_env *, struct _jc_soot_AbstractUnitAllMapTo$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_AbstractUnitAllMapTo$method$get$b30461fc5ea13399(_jc_env *, struct _jc_soot_AbstractUnitAllMapTo$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_AbstractUnitAllMapTo$method_info$entrySet$e1cf6e695274e51f;
extern _jc_method _jc_soot_AbstractUnitAllMapTo$method_info$get$b30461fc5ea13399;

// Virtual methods structure
struct _jc_soot_AbstractUnitAllMapTo$vmethods {
	struct _jc_object	*(*entrySet$e1cf6e695274e51f)(_jc_env *, struct _jc_soot_AbstractUnitAllMapTo$object *);
	struct _jc_java_lang_Object$object	*(*get$b30461fc5ea13399)(_jc_env *, struct _jc_soot_AbstractUnitAllMapTo$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_soot_AbstractUnitAllMapTo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap$vmethods	java_util_AbstractMap;
	_jc_soot_AbstractUnitAllMapTo$vmethods	soot_AbstractUnitAllMapTo;
};

// Vtype
struct _jc_soot_AbstractUnitAllMapTo$vtype {
	_jc_type			type;
	_jc_soot_AbstractUnitAllMapTo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_AbstractUnitAllMapTo$sub_refs {
	struct _jc_java_lang_Object$object	*dest;
};

// Reference instance fields (object)
struct _jc_soot_AbstractUnitAllMapTo$refs {
    _jc_soot_AbstractUnitAllMapTo$sub_refs	soot_AbstractUnitAllMapTo;
    _jc_java_util_AbstractMap$sub_refs	java_util_AbstractMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_AbstractUnitAllMapTo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_AbstractUnitAllMapTo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap$sub_nonrefs	java_util_AbstractMap;
    _jc_soot_AbstractUnitAllMapTo$sub_nonrefs	soot_AbstractUnitAllMapTo;
};

// Object instance structure
struct _jc_soot_AbstractUnitAllMapTo$object {
	_jc_soot_AbstractUnitAllMapTo$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_AbstractUnitAllMapTo$vtype	*vtype;
	_jc_soot_AbstractUnitAllMapTo$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_AbstractUnitAllMapTo$vtype _jc_soot_AbstractUnitAllMapTo$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_AbstractUnitAllMapTo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_AbstractUnitAllMapTo$class_object;

#endif	/* _JC_soot_AbstractUnitAllMapTo_H_ */

==> jc-1.4.6.tar.gz: soot/AbstractUnitAllMapTo.h <==
// public class soot.AbstractUnitAllMapTo

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c7382c60132d0b2c java_util_AbstractMap
// @dep_class 16e0c0c67a652321 soot_AbstractUnitAllMapTo

// header file dependencies
// @dep_header java_util_AbstractMap

#include "java/util/AbstractMap.h"

#ifndef _JC_soot_AbstractUnitAllMapTo_H_
#define _JC_soot_AbstractUnitAllMapTo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_soot_AbstractUnitAllMapTo$sub_refs	_jc_soot_AbstractUnitAllMapTo$sub_refs;
typedef struct _jc_soot_AbstractUnitAllMapTo$sub_nonrefs	_jc_soot_AbstractUnitAllMapTo$sub_nonrefs;
typedef struct _jc_soot_AbstractUnitAllMapTo$refs	_jc_soot_AbstractUnitAllMapTo$refs;
typedef struct _jc_soot_AbstractUnitAllMapTo$nonrefs	_jc_soot_AbstractUnitAllMapTo$nonrefs;
typedef struct _jc_soot_AbstractUnitAllMapTo$object	_jc_soot_AbstractUnitAllMapTo$object;

typedef const struct _jc_soot_AbstractUnitAllMapTo$vmethods	_jc_soot_AbstractUnitAllMapTo$vmethods;
typedef const struct _jc_soot_AbstractUnitAllMapTo$vtable	_jc_soot_AbstractUnitAllMapTo$vtable;
typedef const struct _jc_soot_AbstractUnitAllMapTo$vtype	_jc_soot_AbstractUnitAllMapTo$vtype;

// Constructors
extern void _jc_soot_AbstractUnitAllMapTo$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_soot_AbstractUnitAllMapTo$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_AbstractUnitAllMapTo$method$entrySet$e1cf6e695274e51f(_jc_env *, struct _jc_soot_AbstractUnitAllMapTo$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_AbstractUnitAllMapTo$method$get$b30461fc5ea13399(_jc_env *, struct _jc_soot_AbstractUnitAllMapTo$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_AbstractUnitAllMapTo$method_info$entrySet$e1cf6e695274e51f;
extern _jc_method _jc_soot_AbstractUnitAllMapTo$method_info$get$b30461fc5ea13399;

// Virtual methods structure
struct _jc_soot_AbstractUnitAllMapTo$vmethods {
	struct _jc_object	*(*entrySet$e1cf6e695274e51f)(_jc_env *, struct _jc_soot_AbstractUnitAllMapTo$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*get$b30461fc5ea13399)(_jc_env *, struct _jc_soot_AbstractUnitAllMapTo$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_AbstractUnitAllMapTo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap$vmethods	java_util_AbstractMap;
	_jc_soot_AbstractUnitAllMapTo$vmethods	soot_AbstractUnitAllMapTo;
};

// Vtype
struct _jc_soot_AbstractUnitAllMapTo$vtype {
	_jc_type			type;
	_jc_soot_AbstractUnitAllMapTo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_AbstractUnitAllMapTo$sub_refs {
	struct _jc_java_lang_Object$object	*dest;
};

// Reference instance fields (object)
struct _jc_soot_AbstractUnitAllMapTo$refs {
    _jc_soot_AbstractUnitAllMapTo$sub_refs	soot_AbstractUnitAllMapTo;
    _jc_java_util_AbstractMap$sub_refs	java_util_AbstractMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_AbstractUnitAllMapTo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_AbstractUnitAllMapTo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap$sub_nonrefs	java_util_AbstractMap;
    _jc_soot_AbstractUnitAllMapTo$sub_nonrefs	soot_AbstractUnitAllMapTo;
};

// Object instance structure
struct _jc_soot_AbstractUnitAllMapTo$object {
	_jc_soot_AbstractUnitAllMapTo$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_AbstractUnitAllMapTo$vtype	*vtype;
	_jc_soot_AbstractUnitAllMapTo$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_AbstractUnitAllMapTo$vtype _jc_soot_AbstractUnitAllMapTo$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_AbstractUnitAllMapTo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_AbstractUnitAllMapTo$class_object;

#endif	/* _JC_soot_AbstractUnitAllMapTo_H_ */
